instancelib.feature\_extraction package
=======================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   instancelib.feature_extraction.base
   instancelib.feature_extraction.doc2vec
   instancelib.feature_extraction.textinstance
   instancelib.feature_extraction.textsklearn

Module contents
---------------

.. automodule:: instancelib.feature_extraction
   :members:
   :undoc-members:
   :show-inheritance:
